@@ -245,6 +245,10 @@ thunar_abstract_icon_view_init (ThunarAbstractIconView *abstract_icon_view)
   g_signal_connect (G_OBJECT (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), "sort-column-changed",
                     G_CALLBACK (thunar_abstract_icon_view_sort_column_changed), abstract_icon_view);
   thunar_abstract_icon_view_sort_column_changed (GTK_TREE_SORTABLE (THUNAR_STANDARD_VIEW (abstract_icon_view)->model), abstract_icon_view);
+
+  /* update the icon view on size-allocate events */
+  g_signal_connect_swapped (G_OBJECT (abstract_icon_view), "size-allocate",
+                            G_CALLBACK (gtk_widget_queue_resize), view);
 }
 
 
