@@ -223,7 +223,6 @@ thunar_details_view_init (ThunarDetailsView *details_view)
   gtk_widget_show (tree_view);
 
   /* configure general aspects of the details view */
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree_view), TRUE);
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tree_view), TRUE);
 
   /* enable rubberbanding (if supported) */
@@ -280,7 +279,7 @@ thunar_details_view_init (ThunarDetailsView *details_view)
       else
         {
           /* size is right aligned, everything else is left aligned */
-          renderer = (column == THUNAR_COLUMN_SIZE) ? right_aligned_renderer : left_aligned_renderer;
+          renderer = (column == THUNAR_COLUMN_SIZE || column == THUNAR_COLUMN_SIZE_IN_BYTES) ? right_aligned_renderer : left_aligned_renderer;
 
           /* add the renderer */
           gtk_tree_view_column_pack_start (details_view->columns[column], renderer, TRUE);
@@ -725,7 +724,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
       if (path == NULL)
         {
           /* open the context menu */
-          thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view), event->button, event->time);
+          thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view));
         }
       else
         {
@@ -748,7 +747,7 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
                 }
 
               /* show the context menu */
-              thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view), event->button, event->time);
+              thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view));
             }
           gtk_tree_path_free (path);
         }
@@ -810,7 +809,7 @@ thunar_details_view_key_press_event (GtkTreeView       *tree_view,
   /* popup context menu if "Menu" or "<Shift>F10" is pressed */
   if (event->keyval == GDK_KEY_Menu || ((event->state & GDK_SHIFT_MASK) != 0 && event->keyval == GDK_KEY_F10))
     {
-      thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view), 0, event->time);
+      thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view));
       return TRUE;
     }
 
