@@ -262,7 +262,9 @@ thunar_dialogs_show_about (GtkWindow   *parent,
                          "comments", comments,
                          "copyright", "Copyright \302\251 2004-2011 Benedikt Meurer\n"
                                       "Copyright \302\251 2009-2011 Jannis Pohlmann\n"
-                                      "Copyright \302\251 2009-2012 Nick Schermer",
+                                      "Copyright \302\251 2009-2012 Nick Schermer\n"
+                                      "Copyright \302\251 2017-2018 Alexander Schwinn\n"
+                                      "Copyright \302\251 2017-2018 Andre Miranda",
                          "destroy-with-parent", TRUE,
                          "documenters", documenters,
                          "license", XFCE_LICENSE_GPL,
@@ -270,7 +272,7 @@ thunar_dialogs_show_about (GtkWindow   *parent,
                          "program-name", title,
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
-                         "website", "http://thunar.xfce.org/",
+                         "website", "https://docs.xfce.org/xfce/thunar/Start/",
                          NULL);
 
   /* cleanup */
