@@ -48,7 +48,6 @@ dnd_action_selected (GtkWidget     *item,
  * @widget    : the widget on which the drop was performed.
  * @folder    : the #ThunarFile to which the @path_list is being dropped.
  * @path_list : the #GFile<!---->s of the files being dropped to @file.
- * @timestamp : the time of the drop event.
  * @actions   : the list of actions supported for the drop.
  *
  * Pops up a menu that asks the user to choose one of the
@@ -66,7 +65,6 @@ GdkDragAction
 thunar_dnd_ask (GtkWidget    *widget,
                 ThunarFile   *folder,
                 GList        *path_list,
-                guint         timestamp,
                 GdkDragAction dnd_actions)
 {
   static const GdkDragAction dnd_action_items[] = { GDK_ACTION_COPY, GDK_ACTION_MOVE, GDK_ACTION_LINK };
@@ -168,8 +166,8 @@ thunar_dnd_ask (GtkWidget    *widget,
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   gtk_widget_show (item);
 
-  /* run the menu on the widget's screen (takes over the floating reference of menu) */
-  thunar_gtk_menu_run (GTK_MENU (menu), widget, NULL, NULL, 3, timestamp);
+  /* run the menu (takes over the floating of menu) */
+  thunar_gtk_menu_run (GTK_MENU (menu));
 
   /* cleanup */
   g_object_unref (G_OBJECT (factory));
