@@ -160,13 +160,13 @@ static void
 thunar_history_init (ThunarHistory *history)
 {
   /* create the "back" action */
-  history->action_back = thunar_history_action_new ("back", _("Back"), _("Go to the previous visited folder"), GTK_STOCK_GO_BACK);
+  history->action_back = thunar_history_action_new ("back", _("Back"), _("Go to the previous visited folder"), "go-previous-symbolic");
   g_signal_connect (G_OBJECT (history->action_back), "activate", G_CALLBACK (thunar_history_action_back), history);
   g_signal_connect (G_OBJECT (history->action_back), "show-menu", G_CALLBACK (thunar_history_show_menu), history);
   gtk_action_set_sensitive (history->action_back, FALSE);
 
   /* create the "forward" action */
-  history->action_forward = thunar_history_action_new ("forward", _("Forward"), _("Go to the next visited folder"), GTK_STOCK_GO_FORWARD);
+  history->action_forward = thunar_history_action_new ("forward", _("Forward"), _("Go to the next visited folder"), "go-next-symbolic");
   g_signal_connect (G_OBJECT (history->action_forward), "activate", G_CALLBACK (thunar_history_action_forward), history);
   g_signal_connect (G_OBJECT (history->action_forward), "show-menu", G_CALLBACK (thunar_history_show_menu), history);
   gtk_action_set_sensitive (history->action_forward, FALSE);
@@ -347,12 +347,22 @@ thunar_history_error_not_found (GFile    *goto_file,
                                 gpointer  parent)
 {
   gchar  *parse_name;
+  gchar  *path;
   GError *error = NULL;
 
   g_set_error_literal (&error, G_FILE_ERROR, G_FILE_ERROR_EXIST,
                        _("The item will be removed from the history"));
 
-  parse_name = g_file_get_parse_name (goto_file);
+  path = g_file_get_path (goto_file);
+  if (path == NULL)
+    {
+      path = g_file_get_uri (goto_file);
+      parse_name = g_uri_unescape_string (path, NULL);
+      g_free (path);
+    }
+  else
+    parse_name = g_file_get_parse_name (goto_file);
+
   thunar_dialogs_show_error (parent, error, _("Could not find \"%s\""), parse_name);
   g_free (parse_name);
 
@@ -375,7 +385,7 @@ thunar_history_go_back (ThunarHistory  *history,
 
   /* check if the directory still exists */
   directory = thunar_file_get (goto_file, NULL);
-  if (directory == NULL)
+  if (directory == NULL || ! thunar_file_is_mounted (directory))
     {
       thunar_history_error_not_found (goto_file, NULL);
 
@@ -456,7 +466,7 @@ thunar_history_go_forward (ThunarHistory  *history,
 
   /* check if the directory still exists */
   directory = thunar_file_get (goto_file, NULL);
-  if (directory == NULL)
+  if (directory == NULL || ! thunar_file_is_mounted (directory))
     {
       thunar_history_error_not_found (goto_file, NULL);
 
