@@ -663,7 +663,7 @@ thunar_preferences_dialog_init (ThunarPreferencesDialog *dialog)
   exo_binding_new (G_OBJECT (button), "active", G_OBJECT (label), "sensitive");
   g_signal_connect_swapped (G_OBJECT (label), "activate-link", G_CALLBACK (thunar_preferences_dialog_configure), dialog);
   gtk_label_set_markup (GTK_LABEL (label), _("<a href=\"volman-config:\">Configure</a> the management of removable drives\n"
-                                             "and media (i.e. how cameras should be handled)."));
+                                             "and media (e.g., how cameras should be handled)."));
   gtk_widget_set_hexpand (label, TRUE);
   gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
   gtk_widget_show (label);
