@@ -75,6 +75,7 @@ enum
   PROP_MISC_VOLUME_MANAGEMENT,
   PROP_MISC_CASE_SENSITIVE,
   PROP_MISC_DATE_STYLE,
+  PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT,
   PROP_MISC_FOLDERS_FIRST,
   PROP_MISC_FULL_PATH_IN_TITLE,
   PROP_MISC_HORIZONTAL_WHEEL_NAVIGATES,
@@ -220,7 +221,7 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
       g_param_spec_string ("last-details-view-column-order",
                            "LastDetailsViewColumnOrder",
                            NULL,
-                           "THUNAR_COLUMN_NAME,THUNAR_COLUMN_SIZE,THUNAR_COLUMN_TYPE,THUNAR_COLUMN_DATE_MODIFIED",
+                           "THUNAR_COLUMN_NAME,THUNAR_COLUMN_SIZE,THUNAR_COLUMN_SIZE_IN_BYTES,THUNAR_COLUMN_TYPE,THUNAR_COLUMN_DATE_MODIFIED",
                            EXO_PARAM_READWRITE);
 
   /**
@@ -491,6 +492,22 @@ thunar_preferences_class_init (ThunarPreferencesClass *klass)
                          THUNAR_DATE_STYLE_SIMPLE,
                          EXO_PARAM_READWRITE);
 
+  /**
+   * ThunarPreferences:misc-execute-shell-scripts-by-default:
+   *
+   * Shell scripts are often unsafe to execute, require additional
+   * parameters and most users will only want to edit them in their
+   * favorite editor, so the default is to open them in the associated
+   * application. Setting this to TRUE allows executing them, like
+   * binaries, by default. See bug #7596.
+   **/
+  preferences_props[PROP_EXEC_SHELL_SCRIPTS_BY_DEFAULT] =
+      g_param_spec_boolean ("misc-exec-shell-scripts-by-default",
+                            "MiscExecShellScriptsByDefault",
+                            NULL,
+                            FALSE,
+                            EXO_PARAM_READWRITE);
+
   /**
    * ThunarPreferences:misc-folders-first:
    *
